==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/entry.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once "init_processor.php";
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
if (!isset($_SERVER['QUERY_STRING']) || $_SERVER['QUERY_STRING'] == '') {
  echo 'nan nimo nai.';
  exit();
}
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
?>
<?php
?>
<?php
checkNull($_GET);
checkNull($_POST);
checkNull($_COOKIE);
//entry id
if ($_GET[entry] != ''){
	checkEntryid($_GET[entry]);
}
//不正なはてなID
if ($_GET["user"] != ''){
	checkId($_GET["user"]);
}
//長すぎる keyword
if ($_GET["keyword"] != ''){
	checkKeyword($_GET["keyword"]);
}
//
if ($_GET['image'] == ''){
} else {
	checkImagemode($_GET['image']);
}
if ($_SESSION['image'] == ''){
} else {
	checkImagemode($_SESSION['image']);
}
?>
<?php
if (isset($_GET['image'])){
	$_SESSION['image'] = $_GET['image'];
}
if ($_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
?>
<?php
//
require 'login_processor.php';
// if (isset($_SESSION['oauth_stat'])) session_regenerate_id(TRUE);

//投稿処理の呼び出し。
if (isset($_POST['posting'])){
  require 'post_processor.php';
}
?>
<?php
if ($_GET['entry'] != ''){
	$get_entry = htmlspecialchars($_GET['entry'],ENT_QUOTES);
	$json_url = "{$api_base_url}statuses/show/{$_GET['entry']}.xml";
}
if ($_GET['user'] != ''){
	$get_user = htmlspecialchars($_GET['user'], ENT_QUOTES);
	$get_keyword = htmlspecialchars($_GET['keyword'], ENT_QUOTES);
	$page_head = $get_user . ' さんのエントリー';
	$official = $haiku_official_url . $get_user . '/' . $get_entry;
	$self_anchor = 'http://' . $_SERVER['SERVER_NAME'] . $selfcall . '?entry=' . rawurlencode($_GET['entry']) . '&user=' . rawurlencode($_GET['user']) . '&;keyword='. rawurlencode($_GET['keyword']);
	$self_anchor_possibly_with_pagenum = $self_anchor;
}	elseif ($_GET['user'] == ''){
	$page_head = 'エントリー';
	$official = $haiku_official_url . 'entry' . '/' . $get_entry;
	$self_anchor = 'http://' . $_SERVER['SERVER_NAME'] . $selfcall . '?entry=' . rawurlencode($_GET['entry']);
	$self_anchor_possibly_with_pagenum = $self_anchor;
}
/*if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != ''){*/
  $relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '&with=haiku&callback='.rawurlencode(rawurldecode($relog_back));
/*} else {
  $relog_back = $self_anchor_possibly_with_pagenum . '?log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '?with=haiku&amp;callback='.rawurlencode($relog_back);
}*/
if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on'){
/*	if (preg_match('/^image=on$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif (isset($_GET['log']) && preg_match('/^log=(on|off)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif ($_SERVER["QUERY_STRING"] != ""){*/
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&image=on';
/*	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	}*/
} elseif ($_GET['image'] == 'off' || $_SESSION['image'] == 'off' || $_GET['image'] == '' || $_SESSION['image'] == ''){
/*	if (preg_match('/^image=off$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif (isset($_GET['log']) && preg_match('/^log=(off|on)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif ($_SERVER["QUERY_STRING"] != ""){*/
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&image=off';
/*	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	}*/
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name} {$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
//var_dump($_GET);
echoCommonHeader($relogin, $self_anchor_with_imagemode);
echo "<div id=\"header\" class=\"entry\">\n";
echo "<h1 id=\"entries-head\" class=\"head1\">{$page_head} <a href=\"{$official}\" class=\"to-original-link\">&nbsp;‡&nbsp;</a></h1>\n<hr />";
echo "</div>\n";
  if (isset($_SESSION['post_result']) && $_SESSION['post_result'] === TRUE or FALSE){
  echo '<div class="post-result">';
//   var_dump($_SESSION);
	if ($_SESSION['post_result'] === TRUE){
// 		var_dump($_SESSION['post_to']);
		  $json_body = $_SESSION['post_body'];
		  $contents = checkEntryData($json_body);
		  if ($contents['stat'] == FALSE && $contents['ercode'] != 'x'){
			echo "<p>何かのエラーです。</p>\n";
			print_r(strip_tags($contents['contents']));
			echo "<br />{$json_body}</blockquote>\n";
		  } elseif ($contents['stat'] == FALSE && $contents['ercode'] == 'x'){
			echo "<p>何かのエラーですす。</p>\n";
			echo "<blockquote>{$contents['ermes']}</blockquote>\n";	
		  } else {
			echo '<span>' . $_SESSION['post_result_mes'] . '</span>';
		  }

	}
	if ($_SESSION['post_result'] === FALSE){
		echo '<span>' . $_SESSION['post_result_mes'] . '</span>';
		echo "<blockquote>{$_SESSION['post_error']}</blockquote>";
// 		var_export($_SESSION['$post_session']);
	}
  echo '</div>';
	$_SESSION['post_to'] = '';
	$_SESSION['post_result'] = '';
	$_SESSION['post_result_mes'] = '';
	$_SESSION['post_error'] = '';
	$_SESSION['post_body'] = '';
	libxml_clear_errors();
  }
if (isset($_SESSION['oauth_stat'])){
  echo '<div class="oauth-res">'."\n";
  if ($oauth_stat === TRUE) {
	echo "<span>アクセストークンを更新しました。</span>\n";
  } else {
	echo "<span>アクセストークンを取得できませんでした。</span>\n";
	echo "<blockquote>{$oauth_stat}</blockquote>";
  }
  echo '</div>'."\n";
}
?>
<div class="contents">
<?php
if (isset($_GET['image'])){
	$_SESSION['image'] = $_GET['image'];
}
$request_url = $json_url;
$json = getJson($request_url, FALSE);
if ($json['stat'] !== TRUE){
  $contents = strip_tags($json['stat']);
  echo "<p>はてなハイク API からデータを取得できなかったような気がします。</p>\n";
  echo "<blockquote>{$contents}</blockquote>\n";
} else {
  $contents = simplexml_load_string($json['body']);
  if (libxml_get_last_error() !== FALSE){
	$contents = strip_tags($contents);
	echo "<p>はてなハイク API からデータを取得できなかったような気がします。</p>\n";
	echo "<blockquote>{$contents}</blockquote>\n";
  } elseif (isset($contents['error'])){
	echo "<p>はてなハイク API からデータを取得できなかったような気がします。</p>\n";
	echo "<blockquote>{$contents['error']}</blockquote>\n";	
  } else {
	$entry_processor_mode = "entry";
	$val = $contents;
	require 'entry_processor.php';
	  if ($contents->replies[0]->id != ''){
		echo '<dl><dt>リプライ</dt>';
		echo '<dd>';
		foreach($contents->replies as $val){
			$val->keyword = $_GET['keyword'];
			require 'entry_processor.php';
		}
		echo '</dd>';
		echo '</dl>';
	  }
  }
}

?>
<?php
if ($_SESSION['auth'] === TRUE){
	echo '<dl class="post-box">';
	echo '<dt>リプライする</dt><dd>';
	echo <<<EOL
<form method="post" action="" enctype="application/x-www-form-urlencoded">
<textarea id="post-text" name="status" rows="4" cols="20">
EOL;
	if (isset($_GET['body'])) echo htmlspecialchars($_GET['body']);
  echo <<<EOL
</textarea><br />
<input type="hidden" name="posting" value="status" />
<input type="hidden" name="return" value="
EOL;
  echo htmlspecialchars($self_anchor_possibly_with_pagenum,ENT_QUOTES);
  echo <<<EOL
" />
<input type="hidden" name="in_reply_to_status_id" value="{$get_entry}" />
<input type="submit" id="post-haiku" value="Haiku!" />
<label for="post-from"> from </label><input type="text" id="post-from" name="source" value="{$product_name_abbr}" maxlength="170" />
<a href="./coco.php?
EOL;
// if (isset($_GET['keyword'])) echo '?keyword='.rawurlencode($_GET['keyword']);
echo "return=".rawurlencode($self_anchor_with_imagemode);
echo '" class="navigation-link">イマココ</a>';
echo '</form>';
	echo '</dd>';
/*	if ($_SESSION['post_result'] == 'success'){
		echo '<dd>' . $_SESSION['post_result_mes'] . '</dd>';
	}
	if ($_SESSION['post_result'] == 'failed'){
		echo '<dd>' . $_SESSION['post_result_mes'] . '</dd>';
		echo '<dd>' . $_SESSION['post_error'] . '</dd>';
	}*/
	echo '</dl>';
/*	$_SESSION['post_result'] = '';
	$_SESSION['post_result_mes'] = '';
	$_SESSION['post_error'] = '';*/
}
?>
</div>
<div>
<?php
$navi_paging = FALSE;
$navi_imaging = TRUE;
require 'footer_include.php';
if (isset($_SESSION['oauth_stat'])) unset($_SESSION['oauth_stat']);
?>
</body>
</html>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/entry.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once "init_processor.php";
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
if (!isset($_SERVER['QUERY_STRING']) || $_SERVER['QUERY_STRING'] == '') {
  echo 'nan nimo nai.';
  exit();
}
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
?>
<?php
?>
<?php
//entry id
if (isset($_GET['entry'])) checkEntryid($_GET['entry']);
//不正なはてなID
if (isset($_GET["user"])) checkId($_GET["user"]);
//長すぎる keyword
if (isset($_GET["keyword"])) checkKeyword($_GET["keyword"]);
//
if (isset($_GET['image'])) checkImagemode($_GET['image']);
if (isset($_SESSION['image'])) checkImagemode($_SESSION['image']);
?>
<?php
if (isset($_GET['image'])){
	$_SESSION['image'] = $_GET['image'];
}
if (!isset($_SESSION['auth']) || $_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
?>
<?php
//
require 'login_processor.php';
// if (isset($_SESSION['oauth_stat'])) session_regenerate_id(TRUE);

//投稿処理の呼び出し。
if (isset($_POST['posting'])){
  require 'post_processor.php';
}
?>
<?php
if ($_GET['entry'] != ''){
	$get_entry = htmlspecialchars($_GET['entry'],ENT_QUOTES);
	$json_url = "{$api_base_url}statuses/show/{$_GET['entry']}.xml?body_formats=api,html_touch";
}
if ($_GET['user'] != ''){
	$get_user = htmlspecialchars($_GET['user'], ENT_QUOTES);
	$get_keyword = htmlspecialchars($_GET['keyword'], ENT_QUOTES);
	$page_head = $get_user . ' さんのエントリー';
	$official = $haiku_official_url . $get_user . '/' . $get_entry;
	$self_anchor = 'http://' . $_SERVER['SERVER_NAME'] . $selfcall . '?entry=' . rawurlencode($_GET['entry']) . '&user=' . rawurlencode($_GET['user']) . '&;keyword='. rawurlencode($_GET['keyword']);
	$self_anchor_possibly_with_pagenum = $self_anchor;
}	elseif ($_GET['user'] == ''){
	$page_head = 'エントリー';
	$official = $haiku_official_url . 'entry' . '/' . $get_entry;
	$self_anchor = 'http://' . $_SERVER['SERVER_NAME'] . $selfcall . '?entry=' . rawurlencode($_GET['entry']);
	$self_anchor_possibly_with_pagenum = $self_anchor;
}
/*if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != ''){*/
  $relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '&with=haiku&callback='.rawurlencode(rawurldecode($relog_back));
/*} else {
  $relog_back = $self_anchor_possibly_with_pagenum . '?log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '?with=haiku&amp;callback='.rawurlencode($relog_back);
}*/
if ($get_image == 'on'){
/*	if (preg_match('/^image=on$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif (isset($_GET['log']) && preg_match('/^log=(on|off)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif ($_SERVER["QUERY_STRING"] != ""){*/
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&image=on';
/*	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	}*/
} else {
/*	if (preg_match('/^image=off$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif (isset($_GET['log']) && preg_match('/^log=(off|on)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif ($_SERVER["QUERY_STRING"] != ""){*/
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&image=off';
/*	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	}*/
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name} {$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
//var_dump($_GET);
echoCommonHeader($relogin, $self_anchor_with_imagemode);
echo "<div id=\"header\" class=\"entry\">\n";
echo "<h1 id=\"entries-head\" class=\"head1\">{$page_head} <a href=\"{$official}\" class=\"to-original-link\">&nbsp;‡&nbsp;</a></h1>\n<hr />";
echo "</div>\n";
  if (isset($_SESSION['post_result']) && $_SESSION['post_result'] === TRUE or FALSE){
  echo '<div class="post-result">';
//   var_dump($_SESSION);
	if ($_SESSION['post_result'] === TRUE){
// 		var_dump($_SESSION['post_to']);
		  $json_body = $_SESSION['post_body'];
		  $contents = checkEntryData($json_body);
		  if ($contents['stat'] == FALSE && $contents['ercode'] != 'x'){
			echo "<p>何かのエラーです。</p>\n";
			print_r(strip_tags($contents['contents']));
			echo "<br />{$json_body}</blockquote>\n";
		  } elseif ($contents['stat'] == FALSE && $contents['ercode'] == 'x'){
			echo "<p>何かのエラーですす。</p>\n";
			echo "<blockquote>{$contents['ermes']}</blockquote>\n";	
		  } else {
			echo '<span>' . $_SESSION['post_result_mes'] . '</span>';
		  }

	}
	if ($_SESSION['post_result'] === FALSE){
		echo '<span>' . $_SESSION['post_result_mes'] . '</span>';
		echo "<blockquote>{$_SESSION['post_error']}</blockquote>";
// 		var_export($_SESSION['$post_session']);
	}
  echo '</div>';
	$_SESSION['post_to'] = '';
	$_SESSION['post_result'] = '';
	$_SESSION['post_result_mes'] = '';
	$_SESSION['post_error'] = '';
	$_SESSION['post_body'] = '';
	libxml_clear_errors();
  }
if (isset($_SESSION['oauth_stat'])){
  echo '<div class="oauth-res">'."\n";
  if ($oauth_stat === TRUE) {
	echo "<span>アクセストークンを更新しました。</span>\n";
  } else {
	echo "<span>アクセストークンを取得できませんでした。</span>\n";
	echo "<blockquote>{$oauth_stat}</blockquote>";
  }
  echo '</div>'."\n";
}
?>
<div class="contents">
<?php
if (isset($_GET['image'])){
	$_SESSION['image'] = $_GET['image'];
}
$request_url = $json_url;
$json = getJson($request_url, FALSE);
if ($json['stat'] !== TRUE){
  $contents = strip_tags($json['stat']);
  echo "<p>はてなハイク API からデータを取得できなかったような気がします。</p>\n";
  echo "<blockquote>{$contents}</blockquote>\n";
} else {
  $contents = simplexml_load_string($json['body']);
  if (libxml_get_last_error() !== FALSE){
	$contents = strip_tags($contents);
	echo "<p>はてなハイク API からデータを取得できなかったような気がします。</p>\n";
	echo "<blockquote>{$contents}</blockquote>\n";
  } elseif (isset($contents['error'])){
	echo "<p>はてなハイク API からデータを取得できなかったような気がします。</p>\n";
	echo "<blockquote>{$contents['error']}</blockquote>\n";	
  } else {
	$entry_processor_mode = "entry";
	$val = $contents;
	require 'entry_processor.php';
	  if (isset($contents->replies) && $contents->replies[0]->id != ''){
		echo '<dl><dt>リプライ</dt>';
		echo '<dd>';
		foreach($contents->replies as $val){
			$val->keyword = $_GET['keyword'];
			require 'entry_processor.php';
		}
		echo '</dd>';
		echo '</dl>';
	  }
  }
}

?>
<?php
if (isset($_SESSION['auth']) && $_SESSION['auth'] === TRUE){
	echo '<dl class="post-box">';
	echo '<dt>リプライする</dt><dd>';
	echo <<<EOL
<form method="post" action="" enctype="application/x-www-form-urlencoded">
<textarea id="post-text" name="status" rows="4" cols="20">
EOL;
	if (isset($_GET['body'])) echo htmlspecialchars($_GET['body']);
  echo <<<EOL
</textarea><br />
<input type="hidden" name="posting" value="status" />
<input type="hidden" name="return" value="
EOL;
  echo htmlspecialchars($self_anchor_possibly_with_pagenum,ENT_QUOTES);
  echo <<<EOL
" />
<input type="hidden" name="in_reply_to_status_id" value="{$get_entry}" />
<input type="submit" id="post-haiku" value="Haiku!" />
<label for="post-from"> from </label><input type="text" id="post-from" name="source" value="{$product_name_abbr}" maxlength="170" />
<a href="./coco.php?
EOL;
// if (isset($_GET['keyword'])) echo '?keyword='.rawurlencode($_GET['keyword']);
echo "return=".rawurlencode($self_anchor_with_imagemode);
echo '" class="navigation-link">イマココ</a>';
echo '</form>';
	echo '</dd>';
/*	if ($_SESSION['post_result'] == 'success'){
		echo '<dd>' . $_SESSION['post_result_mes'] . '</dd>';
	}
	if ($_SESSION['post_result'] == 'failed'){
		echo '<dd>' . $_SESSION['post_result_mes'] . '</dd>';
		echo '<dd>' . $_SESSION['post_error'] . '</dd>';
	}*/
	echo '</dl>';
/*	$_SESSION['post_result'] = '';
	$_SESSION['post_result_mes'] = '';
	$_SESSION['post_error'] = '';*/
}
?>
</div>
<div>
<?php
$navi_paging = FALSE;
$navi_imaging = TRUE;
require 'footer_include.php';
if (isset($_SESSION['oauth_stat'])) unset($_SESSION['oauth_stat']);
?>
</body>
</html>
